/* $Id: 68800.h,v 1.2 1998/11/02 04:38:34 brian Exp $
******************************************************************************

   ATI 68800 Series -- register definitions and macros

   Copyright (C) 1998		Brian S. Julin	[bri@forcade.calyx.com]

   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/


#ifndef _ATI_68800_h
#define _ATI_68800_h

#include <ATI/38800.h>

/* Additional registers to VGA GRC (0x3CE) */

#define ATI_EXT_PIO_CTL0	0x50
	#define ATI_GR50_PIO_BASE_NORM		0xce

#define ATI_EXT_PIO_CTL1	0x51
	#define ATI_GR51_PIO_BASE_MASK		0x0f
	#define ATI_GR51_PIO_BASE_NORM		0x01
	#define ATI_GR51_PIO_IDX_MASK		0xc0
	#define ATI_GR51_PIO_IDX_NORM		0x80

/* The ATI extended PIO registers, location set by the above two registers */

#define ATI_SCRATCH0		0x00
#define ATI_SCRATCH1		0x01
#define ATI_SCRATCH2		0x02
#define ATI_SCRATCH3		0x03
#define ATI_SCRATCH4		0x04

#define ATI_MEMCLK_CTL0	0x05
	#define ATI05_CMD_CYCLES		0x0f
	#define ATI05_MEM_CYCLES_MASK		0x30
	#define ATI05_MEM_CYCLE_LEAD1		0x00
	#define ATI05_MEM_CYCLE_LEAD0		0x10
	#define ATI05_MEM_CYCLE_LAG1		0x20
	#define ATI05_MEM_CYCLE_LAG2		0x30
	#define ATI05_MEM_PLANAR_LAG		0x40
	#define ATI05_SLOW_CURSOR_BLINK		0x80

#define ATI_MEMCLK_CTL1		0x06
	#define ATI06_TEXT_FIFO_SIZE_MASK	0x07
	#define ATI06_ROM_CYCLES_MASK		0x70

/* Additional values for Register ATI20 */
	#define ATI20_DISP_FIFO_MASK		0x0f
	#define ATI20_DAC_RS2			0x20
	#define ATI20_DAC_RS3			0x40

/* Additional values for Register ATI26 */
	#define ATI26_DISP_ENB_SKEW2 		0x01
	#define ATI26_SCRATCH			0x08
	#define ATI26_SOLID_ULINE		0x40

/* Additional/different values for Register ATI2B */
	#define ATI2B_IO_ZERO_WAIT		0x04
	#define ATI2B_DBLSCAN_LOCK		0x08
	#define ATI2B_TEXT_LATCH_DELAY		0x40

/* Different values for Register ATI2D */
	#define ATI2D_CURSOR_START_B18		0x01
	#define ATI2D_CURSOR_START_B19		0x02
	#define ATI2D_DISPLAYSTART_B18		0x04
	#define ATI2D_DISPLAYSTART_B19		0x08

#define ATI_BANK_CTL1		0x2E
	#define ATI2E_BANK0_POS_B4		0x01
	#define ATI2E_BANK0_POS_B5		0x02
	#define ATI2E_BANK1_POS_B4		0x04
	#define ATI2E_BANK1_POS_B5		0x08
	#define ATI2E_LOCK_CPUCLK		0x10
	#define ATI2E_HSYNC_START_B0		0x20
	#define ATI2E_HSYNC_START_B1		0x40
	#define ATI2E_HSYNC_START_B2		0x80

/* Different values for Register ATI34 */
	#define ATI34_SCRATCH			0x08
	#define ATI34_FONT_AALIAS_ENB		0x10 
	#define	ATI34_OVERSCAN_ENB    		0x80

/* Different values for Register ATI36 */
	#define ATI36_SCRATCH			0x08
	#define ATI36_LINEAR_TEXT_FB		0x40

/* Different values for Register ATI38 */
	#define ATI38_640X300_HERKY_EMU		0x20
	#define ATI38_SCRATCH			0x80

/* Different values for Register ATI3A */
	#define ATI3A_SCRATCH			0x07

/* Different values for Register ATI3B */
	#define ATI3B_SCRATCH			0xc0

/* Additional values for Register ATI3F */
	#define ATI3F_PLANAR_NOWAIT		0x01
	#define ATI3F_PLANAR16_DELAY_MASK 	0x0e

/* Now the 8514 ATI tack-ons for the accelerator */

#define ATI_OVERSCAN_COLOR_8	0x02ee
#define ATI_OVERSCAN_BLUE_24	0x02ef
#define ATI_OVERSCAN_GREEN_24	0x06ee
#define ATI_OVERSCAN_RED_24	0x06ef
#define ATI_CURSOR_OFFSET_LO	0x0aee
#define ATI_CURSOR_OFFSET_HI	0x0eee
	#define ATI_CURSOR_OFFSET_HI_MASK	0x000f
	#define ATI_CURSOR_OFFSET_HI_ENBL	0x8000
#define ATI_H_CUR_POSN		0x12ee
/* Alternate layout for Configuration Status Register 1 */
	#define ATI_CSR1_8514_ONLY		0x0001
	#define ATI_CSR1_BUS_TYPE		0x000e
		#define ATI_CSR1_BUS_TYPE_ISA		0x0000
		#define ATI_CSR1_BUS_TYPE_EISA		0x0002
		#define ATI_CSR1_BUS_TYPE_MCA16		0x0004
		#define ATI_CSR1_BUS_TYPE_MCA32		0x0006
		#define ATI_CSR1_BUS_TYPE_LB386SX	0x0008
		#define ATI_CSR1_BUS_TYPE_LB386DX	0x000a
		#define ATI_CSR1_BUS_TYPE_LB486		0x000c
		#define ATI_CSR1_BUS_TYPE_PCI		0x000e
	#define ATI_CSR1_MEM_TYPE	0x0070
		#define ATI_CSR1_MEM_TYPE_1M_DRAM		0x0000
		#define ATI_CSR1_MEM_TYPE_1M_VRAM_512SER	0x0010
		#define ATI_CSR1_MEM_TYPE_1OR4M_VRAM_256SER	0x0020
		#define ATI_CSR1_MEM_TYPE_4M_DRAM		0x0030
		#define ATI_CSR1_MEM_TYPE_1M_GDRAM		0x0040
		#define ATI_CSR1_MEM_TYPE_1M_VRAM_512SPL	0x0050
		#define ATI_CSR1_MEM_TYPE_4M_VRAM_256SPL	0x0060
	#define ATI_CSR1_CHIP_DIS	0x080
	#define ATI_CSR1_TST_VCTR_ENA	0x0100
	#define ATI_CSR1_DACTYPE	0x0e00

/* Array contents for sanity checking DAC type against driver module string */
		#define ATI_DAC_ID_CHECK_ARRAY	\
		0x0000, "ATI", "68830", \
		0x0200, "Sierra Semiconductor", "SC1148", \
		0x0200, "IMS", "G173", \
		0x0200, "MU", "9c4870", \
		0x0400, "ATI", "68875", \
		0x0400, "Brooktree Corporation", "Bt 885", \
		0x0400, "Texas Instruments", "TLC 3407-5", \
		0x0600, "Brooktree Corporation", "Bt 47", \
		0x0600, "INMOS", "17", \
		0x0800, "AT&T Microelectronics", "ATT 20C49", \
		0x0800, "Brooktree Corporation", "Bt 48", \
		0x0800, "IMS", "G174", \
		0x0800, "MU", "9c1880" , \
		0x0800, "MU", "9c4190" , \
		0x0800, "Sierra Semiconductor", "SC1502" , \
		0x0a00, "ATI", "68860"

		/* structure for above */
		struct ati_dac_sanity_check_s {
			ggi_u16 regval,
			char *manufacturer,
			char *model
		};

	#define ATI_CSR1_MC_ADR_DECODE	0x1000
	#define ATI_CSR1_CARD_ID	0xe000
/* Alternate layout for Configuration Status Register 2 */
	#define ATI_CSR2_SLOW_SEQ_EN	0x01
	#define ATI_CSR2_MEM_ADDR_DIS	0x0002
	#define ATI_CSR2_ISA_16_ENA	0x0004
	#define ATI_CSR2_KOR_TXT_MODE_ENA		0x0008
	#define ATI_CSR2_LOCAL_BUS_SUPPORT		0x0030
	#define ATI_CSR2_LOCAL_BUS_CONFIG_2		0x0040
	#define ATI_CSR2_LOCAL_BUS_RD_DLY_ENA		0x0080
	#define ATI_CSR2_LOCAL_DAC_EN	0x0100
	#define ATI_CSR2_LOCAL_RDY_EN	0x0200
	#define ATI_CSR2_EEPROM_ADR_SEL	0x0400
	#define ATI_CSR2_GE_STRAP_SEL	0x0800
	#define ATI_CSR2_VESA_RDY	0x1000
	#define ATI_CSR2_Z4GBYTE	0x2000
	#define ATI_CSR2_LOC2_MDRAM	0x4000
#define ATI_V_CUR_POSN		0x16ee
#define ATI_FIFO_DATA_TESTr	0x1aee
#define ATI_CUR_COLOR_0		0x1aee
#define ATI_CUR_COLOR_1		0x1aef
#define ATI_CUR_H_OFFSET	0x1eee
#define ATI_CUR_V_OFFSET	0x1eef
#define ATI_PCI_CTL		0x22ee
	#define ATI_PCI_DAC_RW_WS		0x07
	#define ATI_PCI_TARGET_ABORT_EN		0x08
	#define ATI_PCI_DAC_DLY			0x10
	#define ATI_PCI_DAC_SNOOP_EN		0x20
	#define ATI_PCI_FAST_BURST		0x40
	#define ATI_PCI_FAST_MEM_IO		0x80
#define ATI_LOCAL_CTL		0x32ee
	#define ATI_LOCAL_MED_NPC		0x0001
	#define ATI_LOCAL_LONG_NPC		0x0002
	#define ATI_LOCAL_SHORT_NPC		0x0004
	#define ATI_LOCAL_DAC_BLANK_ADJ		0x0008
	#define ATI_LOCAL_FIFO_TEST		0x0010
	#define ATI_LOCAL_FIFO_TIMING_ADJ	0x0060
	#define ATI_LOCAL_MEM_MAP_ENA		0x0020
	#define ATI_LOCAL_BIOS_ENA		0x0040
	#define ATI_LOCAL_ROM_WAIT		0x0310
	#define ATI_LOCAL_MEM_R_DELAY		0x0c00
	#define ATI_LOCAL_LOCAL_BUS_WAIT	0xf000
	#define ATI_LOCAL_8514IO_WAIT		0xf000
#define ATI_MISC		0x36ee
	#define ATI_MISC_W_STATE_ENA		0x0001
	#define ATI_MISC_HOST_8_ENA		0x0002
	#define ATI_MISC_MEM_SIZE_ALIAS		0x000c
	#define ATI_MISC_DISABLE_VGA		0x0010
	#define ATI_MISC_16_BIT_IO		0x0020
	#define ATI_MISC_DISABLE_DAC		0x0040
	#define ATI_MISC_DLY_LATCH_ENA		0x0080
	#define ATI_MISC_TEST_MODE		0x0100
	#define ATI_MISC_BLK_WR_ENA		0x0400
	#define ATI_MISC_64_DRAW_ENA		0x0800
	#define ATI_MISC_MEM_DATA_SEL		0x1000
	#define ATI_MISC_DLY_LATCH_ENA		0x2000
	#define ATI_MISC_LATCH_FULL_ENA		0x4000
#define ATI_FIFO_TEST_TAG	0x3aee
	#define ATI_FIFO_TEST_TAG_MASK		0x1f
#define ATI_EXT_CUR_COL_0_G	0x3aee
#define ATI_EXT_CUR_COL_0_R	0x3aef
#define ATI_EXT_CUR_COL_1_G	0x3eee
#define ATI_EXT_CUR_COL_1_R	0x3eef
#define ATI_MEM_BNDRY		0x42ee
	#define ATI_MEM_BNDRY_MASK		0x000f
	#define ATI_MEM_BNDRY_ENB		0x0010
/* Additional field in Shadow Set Control Register */
	#define ATI_SHADOW_LOCK_OVERSCAN	0x0040
#define ATI_SCRATCHPAD0		0x52ee
	#define ATI_SCRATCHPAD0_ROMADDR		0x003f
	#define ATI_SCRATCHPAD0_MASK		0xff10
#define ATI_SCRATCHPAD1		0x56ee
/* Additional field in Shadow Set Register */
	#define ATI_SHADOW_LOAD_MASK		0x0300
	#define ATI_SHADOW_LOAD_BOTH		0x0000
	#define ATI_SHADOW_LOAD_DEST		0x0100
	#define ATI_SHADOW_LOAD_SRC		0x0200
#define ATI_MEM_APERT		0x5eee
	#define ATI_MEM_APERT			0x0003
	#define ATI_MEM_APERT			0x000c
	#define ATI_MEM_APERT_LOC_BIG		0xfff0
	#define ATI_MEM_APERT_LOC		0xff00
#define ATI_GE_STAT		0x62ee
	#define ATI_GE_CLIP_OVERRUN		0x000f
	#define ATI_GE_CLIP_INSIDE		0x0100
	#define ATI_GE_CLIP_FLAGS		0x1e00
	#define ATI_GE_ACTIVE			0x2000
	#define ATI_GE_EE_DATA_IN		0x4000
	#define ATI_GE_POINTS_OUTSIDE		0x8000
#define ATI_H_OSCAN		0x62ee
	#define ATI_H_OSCAN_W_R	0x000f
	#define ATI_H_OSCAN_W_L	0x00f0
	#define ATI_H_OSCAN_SYNC_DELAY		0x0700
	#define ATI_H_OSCAN_OSCAN_INV		0x1000
	#define ATI_H_OSCAN_SYN_CONT_SEL	0x2000
	#define ATI_H_OSCAN_HSYN_CONT		0x4000
	#define ATI_H_OSCAN_VSYN_CONT		0x8000
#define ATI_V_OSCAN_TOP		0x66ee
#define ATI_V_OSCAN_BOT		0x66ef
#define ATI_MEM_APERT_CFG	0x6aee
	#define ATI_F_APERT_ENA			0x0400
	#define ATI_FIFO_RD_AHEAD		0x0800
	#define ATI_SCLK_DLY			0x1000
	#define ATI_DEC_BURST_ENA		0x2000
	#define ATI_INC_BURST			0x4000
	#define ATI_PCI_TIMEOUT_DIS		0x8000
	/* Extra/changed fields for 16-bit Graphics Engine Control Register */
	#define ATI_GE_PIXEL_WIDTH		0x0030
		#define ATI_GE_PIXEL_4BPP		0x0000
		#define ATI_GE_PIXEL_8BPP		0x0010
		#define ATI_GE_PIXEL_16BPP		0x0020
		#define ATI_GE_PIXEL_24BPP		0x0030
	#define ATI_GE_16_BIT_COLOR_MODE	0x00c0
		#define ATI_GE_16_BIT_COLOR_555		0x0000
		#define ATI_GE_16_BIT_COLOR_565		0x0040
		#define ATI_GE_16_BIT_COLOR_655		0x0080
		#define ATI_GE_16_BIT_COLOR_664		0x00c0
	#define ATI_GE_MULTIPLEX_PIXELS		0x0100
	#define ATI_GE_24_BIT_COLOR_CONFIG		0x0200
	#define ATI_GE_24_BIT_COLOR_ORDER		0x0400
	#define ATI_GE_DISPLAY_PIXEL_SIZE		0x0400
	#define ATI_GE_DAC_EXT_ADDR		0x3000
	#define ATI_GE_DAC_RS2			0x1000
	#define ATI_GE_DAC_RS3			0x2000
	#define ATI_GE_DAC_8_BIT_EN		0x4000
	#define ATI_GE_DRAW_PIXEL_SIZE		0x8000
#define ATI_EEPROM_CTL		0x7eee
	#define ATI_EE_DATA_OUT			0x0001
	#define ATI_EE_CLK			0x0002
	#define ATI_EE_CS			0x0004
	#define ATI_EE_SELECT			0x0008
	#define ATI_EE_ROM_PAGE_SEL		0x00f0
	#define ATI_EE_BLANK_ADJUST		0x0300
	#define ATI_EE_PIXEL_DELAY		0x0c00
	#define ATI_EE_PASSTHRU_OVERIDE		0x1000
	#define ATI_EE_CARD_SELECT		0xe000
#define ATI_GE_CFGr		0x8eee
#define ATI_ROM_PAGE_SEL	0x92ee
	#define ATI_ROM_PAGE_SEL_MASK		0x00f0
	#define ATI_RPS_BLANK_ADJUST		0x0300
	#define ATI_RPS_PIXEL_DELAY		0x0c00
#define ATI_H_TOTALr		0xb2ee
#define ATI_H_DISP_ENDr		0xb2ef
#define ATI_H_SYNC_STRTr	0xb6ee
#define ATI_H_SYNC_CNTLr	0xbaee
	#define ATI_H_SYNC_WIDTH_MASK		0x001f
	#define ATI_H_SYNC_POL			0x0020
#define ATI_V_TOTALr		0xc2ee
	#define ATI_V_TOTAL_MASK		0x0fff
#define ATI_V_DISP_ENDr		0xc6ee
#define ATI_V_SYNC_STRTr	0xcaee
	#define ATI_V_SYNC_STRT_MASK		0x0fff
#define ATI_VERT_LINE_CNTRr	0xceee
	#define ATI_VERT_LINE_CNTR_MASK		0x0fff
#define ATI_V_SYNC_CNTLr	0xd2ee
	#define ATI_V_SYNC_WIDTH_MASK		0x001f
	#define ATI_V_SYNC_POL			0x0020
#define ATI_DEST_CMP_FN_MASK	0xf2ee
#define ATI_CHIP_ID		0xfaee
	#define ATI_CHIP_CODE			0x03ff
		#define ATI_CHIP_CODE_3			0x0000
		#define ATI_CHIP_CODE_6			0x02f7
		#define ATI_CHIP_CODE_AX		0x017
		#define ATI_CHIP_CODE_LX		0x177
	#define ATI_CHIP_CLASS			0x0c00
	#define ATI_CHIP_REV			0xf000


#endif /* Not defined _ATI_68800_h */

